RealmWorkflowsWithIdActivateWithTypeWithResourceIdPostArgs

Struct RealmWorkflowsWithIdActivateWithTypeWithResourceIdPostArgs 

pub struct RealmWorkflowsWithIdActivateWithTypeWithResourceIdPostArgs {
    pub not_before: Option<String>,
}

Fields

not_before: Option<String>

Optional value representing the time to schedule the first workflow step. The value is either an integer representing the seconds from now, an integer followed by ‘ms’ representing milliseconds from now, or an ISO-8601 date string.