pub struct RealmGroupsWithGroupIdMembersGet<'a, TS: KeycloakTokenSupplier> {
pub realm_admin: &'a KeycloakRealmAdmin<'a, TS>,
pub group_id: &'a str,
}Fields
realm_admin: &'a KeycloakRealmAdmin<'a, TS>Realm admin client
group_id: &'a strImplementations
Sourceimpl<'a, TS> RealmGroupsWithGroupIdMembersGet<'a, TS>
impl<'a, TS> RealmGroupsWithGroupIdMembersGet<'a, TS>
Sourcepub fn brief_representation(
self,
value: impl Into<Option<bool>>,
) -> Builder<'a, Self>
pub fn brief_representation( self, value: impl Into<Option<bool>>, ) -> Builder<'a, Self>
Only return basic information (only guaranteed to return id, username, created, first and last name, email, enabled state, email verification state, federation link, and access. Note that it means that namely user attributes, required actions, and not before are not returned.)